library confirmation_screen;

import 'package:confirmation_screen/cubit/confirmation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'cubit/confirmation_cubit.dart';

export 'cubit/confirmation.dart';

class ConfirmationScreen extends StatelessWidget {
  final String _prompt;
  final ConfirmationCubit _cubit;
  final void Function()? _onConfirmed;

  ConfirmationScreen(
      {super.key,
      required Confirmation confirmation,
      required void Function()? onConfirmed})
      : _prompt = confirmation.prompt,
        _onConfirmed = onConfirmed,
        _cubit = ConfirmationCubit(confirmation);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          const Text(
            "Solve the problem!",
            style: TextStyle(fontSize: 14, color: Colors.black),
          ),
          Text(
            _prompt,
            style: const TextStyle(
                fontWeight: FontWeight.bold, fontSize: 18, color: Colors.black),
          ),
          BlocProvider(
            create: (BuildContext context) => _cubit,
            child: _InputWidget(onConfirmed: _onConfirmed),
          ),
        ],
      ),
    );
  }
}

class _InputWidget extends StatelessWidget {
  final void Function()? onConfirmed;

  const _InputWidget({required this.onConfirmed});

  @override
  Widget build(BuildContext context) {
    return BlocConsumer<ConfirmationCubit, ConfirmationState>(
        listener: (context, state) {
      if (state is Confirmed && onConfirmed != null) {
        onConfirmed!();
      }
    }, builder: (context, state) {
      return Container(
          width: 100,
          height: 40,
          decoration: BoxDecoration(
              border: Border.all(
                color: state is Error ? Colors.redAccent : Colors.grey,
              ),
              borderRadius: const BorderRadius.all(Radius.circular(5))),
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Container(
                color: Colors.lightGreen,
                child: const Padding(
                  padding: EdgeInsets.all(3),
                  child: Icon(Icons.lock, color: Colors.black, size: 34),
                ),
              ),
              Flexible(
                child: Padding(
                  padding: const EdgeInsets.only(left: 3.0),
                  child: TextField(
                    autofocus: true,
                    decoration: const InputDecoration.collapsed(hintText: null),
                    style: const TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 16,
                        color: Colors.black),
                    keyboardType: const TextInputType.numberWithOptions(),
                    inputFormatters: <TextInputFormatter>[
                      FilteringTextInputFormatter.digitsOnly
                    ],
                    onChanged: (value) {
                      BlocProvider.of<ConfirmationCubit>(context)
                          .confirmationValueChanged(value);
                    },
                  ),
                ),
              )
            ],
          ));
    });
  }
}

extension on Confirmation {
  String get prompt {
    switch (operation) {
      case Operation.addition:
        return "$leftInput + $rightInput";
      case Operation.subtraction:
        return "$leftInput - $rightInput";
      case Operation.multiplication:
        return "$leftInput x $rightInput";
    }
  }
}
