import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'confirmation.dart';

abstract class ConfirmationState extends Equatable {
  final Confirmation confirmation;
  const ConfirmationState(this.confirmation);
}

class InitialState extends ConfirmationState {
  @override
  List<Object> get props => [confirmation];

  const InitialState(Confirmation confirmation) : super(confirmation);
}

class Confirmed extends ConfirmationState {
  @override
  List<Object> get props => [confirmation];

  const Confirmed(Confirmation confirmation) : super(confirmation);
}

class Error extends ConfirmationState {
  @override
  List<Object> get props => [confirmation];

  const Error(Confirmation confirmation) : super(confirmation);
}

class ConfirmationCubit extends Cubit<ConfirmationState> {
  int get expected {
    switch (state.confirmation.operation) {
      case Operation.addition:
        return state.confirmation.leftInput + state.confirmation.rightInput;
      case Operation.subtraction:
        return state.confirmation.leftInput - state.confirmation.rightInput;
      case Operation.multiplication:
        return state.confirmation.leftInput * state.confirmation.rightInput;
    }
  }

  ConfirmationCubit(Confirmation confirmation) : super(InitialState(confirmation));

  void confirmationValueChanged(String value) {
    try {
      final intValue = int.parse(value);

      if (intValue == expected) {
        emit(Confirmed(state.confirmation));
      } else {
        emit(Error(state.confirmation));
      }
    } catch (e) {
      emit(Error(state.confirmation));
    }
  }
}